@@ -2,7 +2,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#include "smtk.h"
+#include "config.h"
 #include "smtk-app.h"
 
 int main(int argc, char *argv[])
@@ -13,9 +13,7 @@ int main(int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	SmtkApp *app = smtk_app_new();
-	int result = g_application_run(G_APPLICATION(app), argc, argv);
-	g_object_unref(app);
+	g_autoptr(SmtkApp) app = smtk_app_new();
 
-	return result;
+	return g_application_run(G_APPLICATION(app), argc, argv);
 }
